@@ -14,7 +14,10 @@ class SourceFile : public Source {
 
 public:
   SourceFile(
-      const std::string& path, int skip = 0, const std::string& comment = "") {
+      const std::string& path,
+      int skip = 0,
+      bool skipEmptyRows = true,
+      const std::string& comment = "") {
     try {
       fm_ = boost::interprocess::file_mapping(
           path.c_str(), boost::interprocess::read_only);
@@ -31,7 +34,7 @@ public:
     begin_ = skipBom(begin_, end_);
 
     // Skip lines, if needed
-    begin_ = skipLines(begin_, end_, skip, comment);
+    begin_ = skipLines(begin_, end_, skip, skipEmptyRows, comment);
   }
 
   const char* begin() { return begin_; }
